[Bf-blender-cvs] [ccb104b9c26] blender2.8-workbench: Workbench: Basic Solid Studio

Jeroen Bakker noreply at git.blender.org
Wed Apr 18 08:23:43 CEST 2018


Commit: ccb104b9c26085d799a207046edd6d38be32629b
Author: Jeroen Bakker
Date:   Wed Apr 18 08:20:12 2018 +0200
Branches: blender2.8-workbench
https://developer.blender.org/rBccb104b9c26085d799a207046edd6d38be32629b

Workbench: Basic Solid Studio

Currently uses static lighting. Will become HDRI lighting.
Added do_versions to set default drawtype_solid and drawtype_texture to
OB_LIGHTING_STUDIO. When View3D space is created drawtype_solid and
drawtype_texture are also set to OB_LIGHTING_STUDIO.

Current studio lighting uses a dot product to simulate static lighting.
Will need to be changed in the future with different lighting models.

===================================================================

M	source/blender/blenloader/intern/versioning_280.c
M	source/blender/draw/CMakeLists.txt
A	source/blender/draw/engines/workbench/shaders/solid_studio_frag.glsl
A	source/blender/draw/engines/workbench/shaders/workbench_studio_vert.glsl
M	source/blender/draw/engines/workbench/solid_flat_mode.c
A	source/blender/draw/engines/workbench/solid_studio_mode.c
M	source/blender/draw/engines/workbench/workbench_engine.h
M	source/blender/draw/engines/workbench/workbench_private.h
M	source/blender/draw/intern/draw_manager.c
M	source/blender/editors/space_view3d/space_view3d.c

===================================================================

diff --git a/source/blender/blenloader/intern/versioning_280.c b/source/blender/blenloader/intern/versioning_280.c
index 71074aef9b6..d8314cb232c 100644
--- a/source/blender/blenloader/intern/versioning_280.c
+++ b/source/blender/blenloader/intern/versioning_280.c
@@ -948,4 +948,22 @@ void blo_do_versions_280(FileData *fd, Library *UNUSED(lib), Main *main)
 			}
 		}
 	}
+
+	if (!MAIN_VERSION_ATLEAST(main, 280, 6)) {
+		bScreen *sc;
+		ScrArea *sa;
+		SpaceLink *sl;
+
+		for (sc = main->screen.first; sc; sc = sc->id.next) {
+			for (sa = sc->areabase.first; sa; sa = sa->next) {
+				for (sl = sa->spacedata.first; sl; sl = sl->next) {
+					if (sl->spacetype == SPACE_VIEW3D) {
+						View3D *v3d = (View3D *)sl;
+						v3d->drawtype_solid = OB_LIGHTING_STUDIO;
+						v3d->drawtype_wireframe = OB_LIGHTING_STUDIO;
+					}
+				}
+			}
+		}
+	}
 }
diff --git a/source/blender/draw/CMakeLists.txt b/source/blender/draw/CMakeLists.txt
index 9fae5a6c3af..fc91d674c41 100644
--- a/source/blender/draw/CMakeLists.txt
+++ b/source/blender/draw/CMakeLists.txt
@@ -106,6 +106,7 @@ set(SRC
 	engines/eevee/eevee_volumes.c
 	engines/workbench/workbench_engine.c
 	engines/workbench/solid_flat_mode.c
+	engines/workbench/solid_studio_mode.c
 	engines/external/external_engine.c
 
 	DRW_engine.h
@@ -206,7 +207,9 @@ data_to_c_simple(engines/eevee/shaders/volumetric_scatter_frag.glsl SRC)
 data_to_c_simple(engines/eevee/shaders/volumetric_integration_frag.glsl SRC)
 
 data_to_c_simple(engines/workbench/shaders/solid_flat_frag.glsl SRC)
+data_to_c_simple(engines/workbench/shaders/solid_studio_frag.glsl SRC)
 data_to_c_simple(engines/workbench/shaders/workbench_vert.glsl SRC)
+data_to_c_simple(engines/workbench/shaders/workbench_studio_vert.glsl SRC)
 
 data_to_c_simple(modes/shaders/common_globals_lib.glsl SRC)
 data_to_c_simple(modes/shaders/common_view_lib.glsl SRC)
diff --git a/source/blender/draw/engines/workbench/shaders/solid_studio_frag.glsl b/source/blender/draw/engines/workbench/shaders/solid_studio_frag.glsl
new file mode 100644
index 00000000000..1093e543010
--- /dev/null
+++ b/source/blender/draw/engines/workbench/shaders/solid_studio_frag.glsl
@@ -0,0 +1,11 @@
+uniform vec3 color;
+
+in vec3 normal;
+out vec4 fragColor;
+
+void main()
+{
+	float intensity = dot(normal, vec3(0.0, 0.0, 1.0));
+	vec3 shaded_color = color * intensity;
+	fragColor = vec4(shaded_color, 1.0);
+}
diff --git a/source/blender/draw/engines/workbench/shaders/workbench_studio_vert.glsl b/source/blender/draw/engines/workbench/shaders/workbench_studio_vert.glsl
new file mode 100644
index 00000000000..1ff53691e80
--- /dev/null
+++ b/source/blender/draw/engines/workbench/shaders/workbench_studio_vert.glsl
@@ -0,0 +1,14 @@
+uniform mat4 ModelViewProjectionMatrix;
+uniform mat3 NormalMatrix;
+
+in vec3 pos;
+in vec3 nor;
+
+out vec3 normal;
+
+
+void main()
+{
+	normal = normalize(NormalMatrix * nor);
+	gl_Position = ModelViewProjectionMatrix * vec4(pos, 1.0);
+}
diff --git a/source/blender/draw/engines/workbench/solid_flat_mode.c b/source/blender/draw/engines/workbench/solid_flat_mode.c
index e8d2c61152e..b60792113dd 100644
--- a/source/blender/draw/engines/workbench/solid_flat_mode.c
+++ b/source/blender/draw/engines/workbench/solid_flat_mode.c
@@ -84,12 +84,6 @@ static void workbench_solid_flat_cache_init(void *vedata)
 		int state = DRW_STATE_WRITE_COLOR | DRW_STATE_DEPTH_EQUAL;
 		psl->solid_pass = DRW_pass_create("Solid Pass", state);
 	}
-
-	/* Flat Lighting Pass */
-	{
-		int state = DRW_STATE_WRITE_COLOR | DRW_STATE_DEPTH_EQUAL;
-		psl->lighting_pass = DRW_pass_create("Lighting Pass", state);
-	}
 }
 
 static void workbench_solid_flat_cache_populate(void *vedata, Object *ob)
diff --git a/source/blender/draw/engines/workbench/workbench_engine.h b/source/blender/draw/engines/workbench/workbench_engine.h
index 347633b83e2..306579880ca 100644
--- a/source/blender/draw/engines/workbench/workbench_engine.h
+++ b/source/blender/draw/engines/workbench/workbench_engine.h
@@ -27,6 +27,7 @@
 #define __WORKBENCH_ENGINE_H__
 
 extern DrawEngineType draw_engine_workbench_solid_flat;
+extern DrawEngineType draw_engine_workbench_solid_studio;
 extern RenderEngineType DRW_engine_viewport_workbench_type;
 
 #endif /* __WORKBENCH_ENGINE_H__ */
diff --git a/source/blender/draw/engines/workbench/workbench_private.h b/source/blender/draw/engines/workbench/workbench_private.h
index 500943319cc..1fa7812f4c3 100644
--- a/source/blender/draw/engines/workbench/workbench_private.h
+++ b/source/blender/draw/engines/workbench/workbench_private.h
@@ -38,9 +38,7 @@ typedef struct WORKBENCH_StorageList {
 
 typedef struct WORKBENCH_PassList {
 	struct DRWPass *depth_pass;
-
 	struct DRWPass *solid_pass;
-	struct DRWPass *lighting_pass;
 } WORKBENCH_PassList;
 
 typedef struct WORKBENCH_FrameBufferList {
diff --git a/source/blender/draw/intern/draw_manager.c b/source/blender/draw/intern/draw_manager.c
index 84aff8be786..a147aed308c 100644
--- a/source/blender/draw/intern/draw_manager.c
+++ b/source/blender/draw/intern/draw_manager.c
@@ -905,6 +905,10 @@ static void drw_engines_enable_from_engine(RenderEngineType *engine_type, int dr
 		case OB_SOLID:
 			if (draw_mode_solid == OB_LIGHTING_FLAT) {
 				use_drw_engine(&draw_engine_workbench_solid_flat);
+
+			} else if (draw_mode_solid == OB_LIGHTING_STUDIO) {
+				use_drw_engine(&draw_engine_workbench_solid_studio);
+
 			}
 			break;
 
diff --git a/source/blender/editors/space_view3d/space_view3d.c b/source/blender/editors/space_view3d/space_view3d.c
index 744553dedb7..9234c8c3d77 100644
--- a/source/blender/editors/space_view3d/space_view3d.c
+++ b/source/blender/editors/space_view3d/space_view3d.c
@@ -333,6 +333,8 @@ static SpaceLink *view3d_new(const bContext *C)
 	v3d->gridlines = 16;
 	v3d->gridsubdiv = 10;
 	v3d->drawtype = OB_SOLID;
+	v3d->drawtype_solid = OB_LIGHTING_STUDIO;
+	v3d->drawtype_texture = OB_LIGHTING_STUDIO;
 
 	v3d->gridflag = V3D_SHOW_X | V3D_SHOW_Y | V3D_SHOW_FLOOR;



More information about the Bf-blender-cvs mailing list
diff --git a/source/blender/draw/engines/workbench/solid_flat_mode.c b/source/blender/draw/engines/workbench/solid_studio_mode.c
similarity index 75%
copy from source/blender/draw/engines/workbench/solid_flat_mode.c
copy to source/blender/draw/engines/workbench/solid_studio_mode.c
index e8d2c61152e..386b5b0c690 100644
--- a/source/blender/draw/engines/workbench/solid_flat_mode.c
+++ b/source/blender/draw/engines/workbench/solid_studio_mode.c
@@ -19,11 +19,11 @@
  *
  */
 
-/** \file solid_flat_mode.c
+/** \file solid_studio_mode.c
  *  \ingroup draw_engine
  *
  * Simple engine for drawing color and/or depth.
  * When we only need simple flat shaders.
  */
 
 #include "DRW_render.h"
@@ -33,8 +33,8 @@
 #include "workbench_private.h"
 /* Shaders */
 
-extern char datatoc_solid_flat_frag_glsl[];
-extern char datatoc_workbench_vert_glsl[];
+extern char datatoc_solid_studio_frag_glsl[];
+extern char datatoc_workbench_studio_vert_glsl[];
 
 /* *********** STATIC *********** */
 static struct {
@@ -48,7 +48,7 @@ static struct {
 
 /* Functions */
 
-static void workbench_solid_flat_engine_init(void *UNUSED(vedata))
+static void workbench_solid_studio_engine_init(void *UNUSED(vedata))
 {
 	if (!e_data.depth_sh) {
 		/* Depth pass */
@@ -56,11 +56,11 @@ static void workbench_solid_flat_engine_init(void *UNUSED(vedata))
 
 		/* Shading pass */
 		e_data.solid_sh = DRW_shader_create(
-						datatoc_workbench_vert_glsl, NULL, datatoc_solid_flat_frag_glsl, "\n");
+						datatoc_workbench_studio_vert_glsl, NULL, datatoc_solid_studio_frag_glsl, "\n");
 	}
 }
 
-static void workbench_solid_flat_cache_init(void *vedata)
+static void workbench_solid_studio_cache_init(void *vedata)
 {
 
 	WORKBENCH_Data * data = (WORKBENCH_Data *)vedata;
@@ -84,15 +84,9 @@ static void workbench_solid_flat_cache_init(void *vedata)
 		int state = DRW_STATE_WRITE_COLOR | DRW_STATE_DEPTH_EQUAL;
 		psl->solid_pass = DRW_pass_create("Solid Pass", state);
 	}
-
-	/* Flat Lighting Pass */
-	{
-		int state = DRW_STATE_WRITE_COLOR | DRW_STATE_DEPTH_EQUAL;
-		psl->lighting_pass = DRW_pass_create("Lighting Pass", state);
-	}
 }
 
-static void workbench_solid_flat_cache_populate(void *vedata, Object *ob)
+static void workbench_solid_studio_cache_populate(void *vedata, Object *ob)
 {
 	WORKBENCH_Data * data = (WORKBENCH_Data *)vedata;
 
@@ -118,11 +112,11 @@ static void workbench_solid_flat_cache_populate(void *vedata, Object *ob)
 	}
 }
 
-static void workbench_solid_flat_cache_finish(void *UNUSED(vedata))
+static void workbench_solid_studio_cache_finish(void *UNUSED(vedata))
 {
 }
 
-static void workbench_solid_flat_draw_scene(void *vedata)
+static void workbench_solid_studio_draw_scene(void *vedata)
 {
 	WORKBENCH_Data * data = (WORKBENCH_Data *)vedata;
 	WORKBENCH_PassList *psl = ((WORKBENCH_Data *)vedata)->psl;
@@ -131,24 +125,24 @@ static void workbench_solid_flat_draw_scene(void *vedata)
 	DRW_draw_pass(psl->solid_pass);
 }
 
-static void workbench_solid_flat_engine_free(void)
+static void workbench_solid_studio_engine_free(void)
 {
 	DRW_SHADER_FREE_SAFE(e_data.solid_sh);
 }
 
 static const DrawEngineDataSize workbench_data_size = DRW_VIEWPORT_DATA_SIZE(WORKBENCH_Data);
 
-DrawEngineType draw_engine_workbench_solid_flat = {
+DrawEngineType draw_engine_workbench_solid_studio = {
 	NULL, NULL,
 	N_("Workbench"),
 	&workbench_data_size,
-	&workbench_solid_flat_engine_init,
-	&workbench_solid_flat_engine_free,
-	&workbench_solid_flat_cache_init,
-	&workbench_solid_flat_cache_populate,
-	&workbench_solid_flat_cache_finish,
+	&workbench_solid_studio_engine_init,
+	&workbench_solid_studio_engine_free,
+	&workbench_solid_studio_cache_init,
+	&workbench_solid_studio_cache_populate,
+	&workbench_solid_studio_cache_finish,
 	NULL,
-	&workbench_solid_flat_draw_scene,
+	&workbench_solid_studio_draw_scene,
 	NULL,
 	NULL,
 	NULL,
@@ -19,11 +19,11 @@
  *
  * Simple engine for drawing color and/or depth.
- * When we only need simple flat shaders.
+ * When we only need simple studio shaders.
  */
 